package envoy.client.ui.controller;

import javafx.fxml.FXML;
import javafx.scene.control.*;

import envoy.client.net.Client;
import envoy.client.ui.SceneContext;
import envoy.client.ui.settings.*;

/**
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>SettingsSceneController.java</strong><br>
 * Created: <strong>10.04.2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Client v0.1-beta
 */
public class SettingsScene {

	@FXML
	private ListView<SettingsPane> settingsList;

	@FXML
	private TitledPane titledPane;

	private SceneContext sceneContext;

	/**
	 * @param sceneContext enables the user to return to the chat scene
	 * @param client       the {@code Client} used to get the current user and to
	 *                     check if this user is online
	 * @since Envoy Client v0.1-beta
	 */
	public void initializeData(SceneContext sceneContext, Client client) {
		this.sceneContext = sceneContext;
		settingsList.getItems().add(new GeneralSettingsPane());
		settingsList.getItems().add(new UserSettingsPane(sceneContext, client.getSender(), client.isOnline()));
		settingsList.getItems().add(new DownloadSettingsPane(sceneContext));
	}

	@FXML
	private void initialize() {
		settingsList.setCellFactory(listView -> new ListCell<>() {

			@Override
			protected void updateItem(SettingsPane item, boolean empty) {
				super.updateItem(item, empty);
				if (!empty && item != null) setGraphic(new Label(item.getTitle()));
			}
		});
	}

	@FXML
	private void settingsListClicked() {
		final var pane = settingsList.getSelectionModel().getSelectedItem();
		if (pane != null) {
			titledPane.setText(pane.getTitle());
			titledPane.setContent(pane);
		}
	}

	@FXML
	private void backButtonClicked() { sceneContext.pop(); }
}
